Learn R Programming

ActuarialM (version 0.1.0)

BellB12 distribution: Bell Burr-12 distribution

Description

Computes the value at risk and expected shortfall based on the Bell Burr-12 (BellB12) distribution. The CDF of the Bell G family is as follows: $$ H(x)=\frac{1-\exp\left[-e^{\lambda}\left(1-e^{-\lambda K(x)}\right)\right]}{1-\exp\Bigl(1-e^{\lambda}\Bigr)};\qquad\lambda>0, $$ where K(x) represents the baseline Burr-12 CDF, it is given by $$ K\left(x\right)=1-\left[1+\left(\frac{x}{a}\right)^{b}\right]^{-k};\qquad a,b,k>0. $$ By setting K(x) in the above Equation, yields the CDF of the BellB12 distribution. The following expression can be used to calculate the VaR: $$ VaR_{p}(X)=a\left(\left[\left(\frac{1}{\lambda}\left[\ln\left(\left[\ln\left(1-p\left[1-\exp\Bigl(1-e^{\lambda}\Bigr)\right]\right)\right]+e^{\lambda}\right)\right]\right)\right]^{-1/k}-1\right)^{1/b},$$

where \(p \in (0,1)\). The ES can be computed from the following expression: $$ES_{p}(X)=\frac{a}{p}\intop_{0}^{p}\left(\left[\left(\frac{1}{\lambda}\left[\ln\left(\left[\ln\left(1-z\left[1-\exp\Bigl(1-e^{\lambda}\Bigr)\right]\right)\right]+e^{\lambda}\right)\right]\right)\right]^{-1/k}-1\right)^{1/b}dz.$$

Usage

vBellB12(p, a, b, k, lambda, log.p = FALSE, lower.tail = TRUE)
eBellB12(p, a, b, k, lambda)

Value

vBellB12 gives the value at risk. eBellB12 gives the expected shortfall.

Arguments

p

A vector of probablities \(p \in (0,1)\).

lambda

The strictly positive parameter of the Bell G family (\(\lambda > 0\)).

a

The strictly positive scale parameter of the baseline Burr-12 distribution (\(a > 0\)).

b

The strictly positive shape parameter of the baseline Burr-12 distribution (\(b > 0\)).

k

The strictly positive shape parameter of the baseline Burr-12 distribution (\(k > 0\)).

lower.tail

if FALSE then 1-H(x) are returned and quantiles are computed for 1-p.

log.p

if TRUE then log(H(x)) are returned and quantiles are computed for exp(p).

Author

Muhammad Imran and M.H. Tahir.

R implementation and documentation: Muhammad Imran imranshakoor84@yahoo.com and M.H. Tahir mht@iub.edu.pk.

Details

The functions allow to compute the value at risk and the expected shortfall of the BellB12 distribution.

References

Fayomi, A., Tahir, M. H., Algarni, A., Imran, M., & Jamal, F. (2022). A new useful exponential model with applications to quality control and actuarial data. Computational Intelligence and Neuroscience, 2022.

Alsadat, N., Imran, M., Tahir, M. H., Jamal, F., Ahmad, H., & Elgarhy, M. (2023). Compounded Bell-G class of statistical models with applications to COVID-19 and actuarial data. Open Physics, 21(1), 20220242.

Zimmer, W. J., Keats, J. B., & Wang, F. K. (1998). The Burr XII distribution in reliability analysis. Journal of quality technology, 30(4), 386-394.

See Also

eBellBX, eBellL

Examples

Run this code
p=runif(10,min=0,max=1)
vBellB12(p,1,1,2,1.2)
eBellB12(p,1,1,2,1.2)

Run the code above in your browser using DataLab