Learn R Programming

ActuarialM (version 0.1.0)

BellBX distribution: Bell Burr-X distribution

Description

Computes the value at risk and expected shortfall based on the Bell Burr-X (BellBX) distribution. The CDF of the Bell G family is as follows: $$ H(x)=\frac{1-\exp\left[-e^{\lambda}\left(1-e^{-\lambda K(x)}\right)\right]}{1-\exp\Bigl(1-e^{\lambda}\Bigr)};\qquad\lambda>0, $$ where K(x) represents the baseline Burr-X CDF, it is given by $$ K(x)=\left[1-\exp(-x^{2})\right]^{a};\qquad a>0. $$ By setting K(x) in the above Equation, yields the CDF of the BellBX distribution. The following expression can be used to calculate the VaR: $$ VaR_{p}(X)=\left(-\ln\left[1-\left\{ 1-\left(\frac{1}{\lambda}\left[\ln\left(\left[\ln\left(1-p\left[1-\exp\Bigl(1-e^{\lambda}\Bigr)\right]\right)\right]+e^{\lambda}\right)\right]\right)\right\} ^{1/a}\right]\right)^{0.5},$$

where \(p \in (0,1)\). The ES can be computed from the following expression: $$ES_{p}(X)=\frac{1}{p}\intop_{0}^{p}\left(-\ln\left[1-\left\{ 1-\left(\frac{1}{\lambda}\left[\ln\left(\left[\ln\left(1-z\left[1-\exp\Bigl(1-e^{\lambda}\Bigr)\right]\right)\right]+e^{\lambda}\right)\right]\right)\right\} ^{1/a}\right]\right)^{0.5}dz.$$

Usage

vBellBX(p, a, lambda, log.p = FALSE, lower.tail = TRUE)
eBellBX(p, a, lambda)

Value

vBellBX gives the value at risk. eBellBX gives the expected shortfall.

Arguments

p

A vector of probablities \(p \in (0,1)\).

lambda

The strictly positive parameter of the Bell G family (\(\lambda > 0\)).

a

The strictly positive scale parameter of the baseline Burr-X distribution (\(a > 0\)).

lower.tail

if FALSE then 1-H(x) are returned and quantiles are computed for 1-p.

log.p

if TRUE then log(H(x)) are returned and quantiles are computed for exp(p).

Author

Muhammad Imran and M.H. Tahir.

R implementation and documentation: Muhammad Imran imranshakoor84@yahoo.com and M.H. Tahir mht@iub.edu.pk.

Details

The functions allow to compute the value at risk and the expected shortfall of the BellBX distribution.

References

Fayomi, A., Tahir, M. H., Algarni, A., Imran, M., & Jamal, F. (2022). A new useful exponential model with applications to quality control and actuarial data. Computational Intelligence and Neuroscience, 2022.

Alsadat, N., Imran, M., Tahir, M. H., Jamal, F., Ahmad, H., & Elgarhy, M. (2023). Compounded Bell-G class of statistical models with applications to COVID-19 and actuarial data. Open Physics, 21(1), 20220242.

Kleiber, C., & Kotz, S. (2003). Statistical size distributions in economics and actuarial sciences. John Wiley & Sons.

See Also

eBellB12, eBellL

Examples

Run this code
p=runif(10,min=0,max=1)
vBellBX(p,1.2,2)
eBellBX(p,1.2,2)

Run the code above in your browser using DataLab