Computes the value at risk and expected shortfall based on the Bell exponentiated exponential (BellEE) distribution. The CDF of the Bell G family is as follows: $$ H(x)=\frac{1-\exp\left[-e^{\lambda}\left(1-e^{-\lambda K(x)}\right)\right]}{1-\exp\Bigl(1-e^{\lambda}\Bigr)};\qquad\lambda>0, $$ where K(x) represents the baseline exponentiated exponential CDF, it is given by $$ K(x)=\left[1-\exp(-\alpha x)\right]^{\beta};\qquad\alpha,\beta>0. $$ By setting K(x) in the above Equation, yields the CDF of the BellEE distribution. The following expression can be used to calculate the VaR: $$VaR_{p}(X)=\frac{-1}{\alpha}\ln\left[1-\left(1-\left(\frac{1}{\lambda}\left[\ln\left(\left[\ln\left(1-p\left[1-\exp\Bigl(1-e^{\lambda}\Bigr)\right]\right)\right]+e^{\lambda}\right)\right]\right)\right)^{1/\beta}\right],$$ where \(p \in (0,1)\). The ES can be computed from the following expression: $$ES_{p}(X)=\frac{1}{p}\intop_{0}^{p}\left[\frac{-1}{\alpha}\ln\left[1-\left(1-\left(\frac{1}{\lambda}\left[\ln\left(\left[\ln\left(1-z\left[1-\exp\Bigl(1-e^{\lambda}\Bigr)\right]\right)\right]+e^{\lambda}\right)\right]\right)\right)^{1/\beta}\right]\right]dz.$$
vBellEE(p, alpha, beta, lambda, log.p = FALSE, lower.tail = TRUE)
eBellEE(p, alpha, beta, lambda)vBellEE gives the value at risk. eBellEE gives the expected shortfall.
A vector of probablities \(p \in (0,1)\).
The strictly positive parameter of the Bell G family of distributions \(\lambda > 0\).
The strictly positive scale parameter of the baseline exponentiated exponential distribution (\(\alpha > 0\)).
The strictly positive shape parameter of the baseline exponentiated exponential distribution (\(\beta > 0\)).
if FALSE then 1-H(x) are returned and quantiles are computed for 1-p.
if TRUE then log(H(x)) are returned and quantiles are computed for exp(p).
Muhammad Imran and M.H. Tahir.
R implementation and documentation: Muhammad Imran imranshakoor84@yahoo.com and M.H. Tahir mht@iub.edu.pk.
The functions allow to compute the value at risk and the expected shortfall of the BellEE distribution.
Fayomi, A., Tahir, M. H., Algarni, A., Imran, M., & Jamal, F. (2022). A new useful exponential model with applications to quality control and actuarial data. Computational Intelligence and Neuroscience, 2022.
Alsadat, N., Imran, M., Tahir, M. H., Jamal, F., Ahmad, H., & Elgarhy, M. (2023). Compounded Bell-G class of statistical models with applications to COVID-19 and actuarial data. Open Physics, 21(1), 20220242.
Nadarajah, S. (2011). The exponentiated exponential distribution: a survey. AStA Advances in Statistical Analysis, 95, 219-251.
eBellEW, eBellE
p=runif(10,min=0,max=1)
vBellEE(p,1,1.2,2)
eBellEE(p,1,1.2,2)
Run the code above in your browser using DataLab